;; Generated package description from mpdired.el  -*- no-byte-compile: t -*-
(define-package "mpdired" "1pre0.20240310.181940" "A dired-like client for Music Player Daemon" '((emacs "29")) :commit "a1d613a6d5b3bd819a1afdc24e4ef2ad70e61f6d" :url "https://elpa.gnu.org/packages/mpdired.html" :authors '(("Manuel Giraud" . "manuel@ledu-giraud.fr")) :maintainer '("Manuel Giraud" . "manuel@ledu-giraud.fr") :keywords '("multimedia"))
